@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yaml
 version: 0.8.16
-id: yaml-0.8.16-d3d7ff6fb3ea07062f7f4203706ad9cb
-key: yaml_83wNkjdxHWcLf5RV9Ar69S
+id: yaml-0.8.16-dde1f04caad6e58716b323c82d57d5b4
+key: yaml_KljSP4k21h80PhjuA45xgb
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: stable
@@ -23,19 +23,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yaml-0.8.16
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yaml-0.8.16
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yaml-0.8.16
-hs-libraries: HSyaml-0.8.16-83wNkjdxHWcLf5RV9Ar69S
+hs-libraries: HSyaml-0.8.16-KljSP4k21h80PhjuA45xgb
 depends:
-    aeson-0.11.1.0-01f93b6d659087121e16b9df8deda57c
-    attoparsec-0.13.0.1-c82a92403ed30683a5cb6228370c626c
+    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
+    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     enclosed-exceptions-1.0.1.1-609f4f396c20c8289c1e73bde62fbdf4
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
-    scientific-0.3.4.5-648b7dc78cf09ce28c222dfd7438d54f
+    scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
     semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
